#
# spec file for package blobby
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           blobby
Version:        1.1.1
Release:        1.1
Summary:        2D Arcade Beach Volleyball Game
License:        GPL-2.0-or-later
Group:          Amusements/Games/Action/Other
URL:            https://blobbyvolley.de/
Source0:        https://github.com/danielknobe/blobbyvolley2/archive/v%{version}.tar.gz#/blobbyvolley2-%{version}.tar.gz
# PATCH-FIX-UPSTREAM blobbyvolley2-fix-non-void-return.patch - fixes control reaches end of non-void function
Patch0:         blobbyvolley2-fix-non-void-return.patch
# PATCH-FIX-OPENSUSE don't use integrated tinyxml
Patch1:         blobbyvolley2-1.1.1_external_tinyxml.patch
BuildRequires:  boost-devel
BuildRequires:  cmake >= 3.7
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  make
BuildRequires:  perl
BuildRequires:  physfs-devel
BuildRequires:  pkgconfig
BuildRequires:  zip
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(tinyxml2)

%description
Blobby Volley is one of the most popular freeware games. This is caused
first by the simple play principle and second by the funny design of
the player. The short duration of a game is a reason for playing this
game in meantime.

%prep
%autosetup -p1 -n blobbyvolley2-%{version}

%build
%cmake
%make_build

%install
%cmake_install

%fdupes %{buildroot}%{_datadir}/%{name}

%files
%doc AUTHORS ChangeLog
%license COPYING
%{_bindir}/*
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/128x128/apps/%{name}.png
%{_datadir}/metainfo/%{name}.appdata.xml

%changelog
* Fri May  2 2025 Dirk Stoecker <opensuse@dstoecker.de>
- add blobbyvolley2-1.1.1_external_tinyxml.patch to use system tinyxml2
* Tue Apr 29 2025 Carsten Ziepke <kieltux@gmail.com>
- Add blobbyvolley2-fix-non-void-return.patch
* Sun Apr 13 2025 Carsten Ziepke <kieltux@gmail.com>
- Update to 1.1.1
  * fix server crash
  * fix ruleset misbehavior (four ball touches possible)
  * improved server log
  * added official macos build support
- Changes in 1.1.0
  * new languages added and some parts of old translations
    corrected
  * new high resolution icon
  * reworked online game lobby and matchmaking
  * added different game settings (rules, final scores and speeds)
    possible on the same server
  * bot scripting overhaul
  * new xml based replay file format
  * a lot of minor improvements and maintenance
  * bugfixes
- Run spec-cleaner
- Drop reproducible.patch, fixed upstream
- Drop networkmessage.patch, fixed upstream
- Drop icon.patch, fixed upstream
- Drop data-dir.patch, fixed upstream
* Sun Jan 10 2021 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch use cmake zip to not add timestamps (boo#1047218)
* Tue Dec 29 2020 Matthias Mailänder <mailaender@opensuse.org>
- Update to version 1.0 at new source code location
- Now using https://en.opensuse.org/SourceUrls
- Drop blobby-BotAPICalculations.diff
- Add networkmessage.patch
- Add icon.patch
- Add data-dir.patch
- Add support for https://en.opensuse.org/openSUSE:AppStore
- Update icon and .desktop file (via FlatHub)
- Use cmake macros
* Sun May  3 2015 dap.darkness@gmail.com
- Updated to rev#1593 to resolve openSUSE:Factory build failures.
- Fixed License tag: "either version 2 … or … any later version".
- Added blobby-BotAPICalculations.diff vs. missing source.
* Mon Jun  2 2014 mailaender@opensuse.org
- update to 1.0
* Tue Dec  3 2013 mailaender@opensuse.org
- update to 1.0 RC4
* Mon Nov 18 2013 mailaender@opensuse.org
- update to 1.0 RC3
- patches are now included upstream
- icon: black border to transparency
* Wed Jan  9 2013 joop.boonen@opensuse.org
- Added BuildRequires zlib-devel as it's not automatically
  installed for openSUSE > 12.2
* Fri May 25 2012 joop.boonen@opensuse.org
- Updated to version 1.0rc1
- Created a gcc 47 patch
- Cleaned the spec file up
* Wed Mar 28 2012 jengelh@medozas.de
- Build in parallel with %%_smp_mflags
- Strip redundant sections/tags from specfile
- Remove already automatically-determined runtime Requires on
  SDL, physfs
* Wed Jul  8 2009 dominique-obs@leuenberger.net
- bnc#511268 fix undefined code
- Add blobby-datadir patch (specifies where to look for the data)
- Drop the shell script, as it's obsoleted with above patch
- rename package to blobby, to be in line with other RPM based
  distros, provide / osbolete blobbyvolley and blobby2
  (previous used names in Factory in games repo)
- Version 0.6.0.1: It's somewhere between 0.6 and 0.7.
* Mon Nov 24 2008 pzimmer@suse.de
- bnc#442864 delete replaced by delete []
* Thu Nov 20 2008 ro@suse.de
- buildrequire only boost-devel, not boost
* Wed Jul 23 2008 pkirsch@suse.de
- added ExclusiveArch Tag: x86, x86_64, ppc, ppc64
* Tue Jul 22 2008 pkirsch@suse.de
- added blobby bash script which checks for user configuration
  data, if not present copied from /usr/share/games/blobbyvolley
* Wed Jul 16 2008 pkirsch@suse.de
- initial checkin
- fixed the missing include <algorithm> in some cpp files
